@@ -76,9 +76,9 @@ class MainHandler(tornado.web.RequestHandler):
             from the HTTP library it is using.
 
 
-            :param status_code: the real HTTP status code of the HTTP response.
+            @param status_code: the real HTTP status code of the HTTP response.
 
-            :param response: an instance of ``base_http_handler.HttpResponse``
+            @param response: an instance of ``base_http_handler.HttpResponse``
                 corresponding to the real HTTP response to be returned to the
                 client application.
             """
@@ -95,7 +95,7 @@ class MainHandler(tornado.web.RequestHandler):
             * ``response``: The embedded response's object.
 
 
-            :return: String representation of the JSON expression that decorates
+            @return: String representation of the JSON expression that decorates
                 the result returned by the method that has processed the HTTP
                 request.
             """
@@ -141,14 +141,14 @@ class MainHandler(tornado.web.RequestHandler):
         the HTTP method and the URL of this request.
 
 
-        :param http_method: An item of the enumeration `HttpMethod`.
+        @param http_method: An item of the enumeration `HttpMethod`.
 
 
-        :return: A ``HttpMethodSpec`` instance wrapping a class inheriting
+        @return: A ``HttpMethodSpec`` instance wrapping a class inheriting
             from ``HttpRequestHandler``.
 
 
-        :raise HandlerNotFoundException: If the specified URI path doesn't
+        @raise HandlerNotFoundException: If the specified URI path doesn't
             match any HTTP handler for the given HTTP method.
         """
         self._logger.debug(f'Searching HTTP handler for "{http_method} {uri_path}"...')
@@ -177,12 +177,12 @@ class MainHandler(tornado.web.RequestHandler):
         http://book.cakephp.org/1.3/en/The-Manual/Common-Tasks-With-CakePHP/REST.html).
 
 
-        :param request: A `tornado.httputil.HTTPServerRequest` instance
+        @param request: A `tornado.httputil.HTTPServerRequest` instance
             containing additional request parameters including headers and
             body data.
 
 
-        :return: an item of the enumeration `HttpMethod`.
+        @return: an item of the enumeration `HttpMethod`.
         """
         # Check whether the client application requests the RESTful API server
         # to override the method specified in the request by whether passing the
@@ -202,12 +202,12 @@ class MainHandler(tornado.web.RequestHandler):
         the HTTP request sent to the RESTful API server.
 
 
-        :param request: A `tornado.httputil.HTTPServerRequest` instance
+        @param request: A `tornado.httputil.HTTPServerRequest` instance
             containing additional request parameters including headers and
             body data.
 
 
-        :return: A list of `HttpRequest.HttpRequestUploadedFile` instances.
+        @return: A list of `HttpRequest.HttpRequestUploadedFile` instances.
         """
         return [
             HttpRequest.HttpRequestUploadedFile(
@@ -357,9 +357,9 @@ def discover_http_handlers(app_path, logger):
     third party Python libraries installed with `easy_install`.
 
 
-    :param app_path: Absolute path of the RESTful API server application.
+    @param app_path: Absolute path of the RESTful API server application.
 
-    :param logger: The logger of the RESTful API server application.
+    @param logger: The logger of the RESTful API server application.
 
 
     :todo: compiled Python files MUST be supported. These files are more
@@ -399,15 +399,15 @@ def boot(port, app_path, address=None):
     processing HTTP request for a given endpoint and HTTP method.
 
 
-    :param address: Address to bound the listening socket to.  Address may
+    @param address: Address to bound the listening socket to.  Address may
         be either an IP address or hostname.  If it’s a hostname, the
         server will listen on all IP addresses associated with the name.
         Address may be an empty string or `None` to listen on all
         available interfaces.
 
-    :param port: Port to bound the listening socket to.
+    @param port: Port to bound the listening socket to.
 
-    :param app_path: Absolute path of the RESTful API server application.
+    @param app_path: Absolute path of the RESTful API server application.
     """
     # Retrieve the logger with the specified name or, if name is `None`,
     # the logger which is the root logger of the hierarchy.
@@ -424,4 +424,3 @@ def boot(port, app_path, address=None):
 
     application.listen(port, address)
     tornado.ioloop.IOLoop.current().start()
-
